@@ -384,14 +384,19 @@ static void
 update_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 {
 	GsUpdateMonitor *monitor = GS_UPDATE_MONITOR (data);
+	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) list = NULL;
 
 	/* get result */
-	list = gs_plugin_loader_job_process_finish (GS_PLUGIN_LOADER (object), res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
-		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
-			g_warning ("failed update application: %s", error->message);
+		gs_plugin_loader_claim_error (plugin_loader,
+					      NULL,
+					      GS_PLUGIN_ACTION_UPDATE,
+					      NULL,
+					      TRUE,
+					      error);
 		return;
 	}
 
@@ -423,16 +428,21 @@ static void
 download_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 {
 	GsUpdateMonitor *monitor = GS_UPDATE_MONITOR (data);
+	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) list = NULL;
 	g_autoptr(GsAppList) update_online = NULL;
 	g_autoptr(GsAppList) update_offline = NULL;
 
 	/* get result */
-	list = gs_plugin_loader_job_process_finish (GS_PLUGIN_LOADER (object), res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
-		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
-			g_warning ("failed to get updates: %s", error->message);
+		gs_plugin_loader_claim_error (plugin_loader,
+					      NULL,
+					      GS_PLUGIN_ACTION_DOWNLOAD,
+					      NULL,
+					      TRUE,
+					      error);
 		return;
 	}
 
@@ -453,6 +463,7 @@ download_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 		g_autoptr(GsPluginJob) plugin_job = NULL;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_UPDATE,
 						 "list", update_online,
+						 "propagate-error", TRUE,
 						 NULL);
 		gs_plugin_loader_job_process_async (monitor->plugin_loader,
 						    plugin_job,
@@ -475,6 +486,7 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 	guint64 security_timestamp_old = 0;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) apps = NULL;
+	gboolean should_download;
 
 	/* get result */
 	apps = gs_plugin_loader_job_process_finish (GS_PLUGIN_LOADER (object), res, &error);
@@ -509,7 +521,9 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 
 	g_debug ("got %u updates", gs_app_list_length (apps));
 
-	if (should_download_updates (monitor) &&
+	should_download = should_download_updates (monitor);
+
+	if (should_download &&
 	    (security_timestamp_old != security_timestamp ||
 	    check_if_timestamp_more_than_days_ago (monitor, "install-timestamp", 14))) {
 		g_autoptr(GsPluginJob) plugin_job = NULL;
@@ -520,6 +534,7 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 		 * preferences */
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_DOWNLOAD,
 						 "list", apps,
+						 "propagate-error", TRUE,
 						 NULL);
 		g_debug ("Getting updates");
 		gs_plugin_loader_job_process_async (monitor->plugin_loader,
@@ -528,8 +543,49 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 						    download_finished_cb,
 						    monitor);
 	} else {
-		notify_about_pending_updates (monitor, apps);
+		g_autoptr(GsAppList) update_online = NULL;
+		g_autoptr(GsAppList) update_offline = NULL;
+		GsAppList *notify_list;
 
+		update_online = gs_app_list_new ();
+		update_offline = gs_app_list_new ();
+		for (guint i = 0; i < gs_app_list_length (apps); i++) {
+			GsApp *app = gs_app_list_index (apps, i);
+			if (_should_auto_update (app)) {
+				g_debug ("download for auto-update %s", gs_app_get_unique_id (app));
+				gs_app_list_add (update_online, app);
+			} else {
+				gs_app_list_add (update_offline, app);
+			}
+		}
+
+		g_debug ("Received %u apps to update, %u are online and %u offline updates; will%s download online updates",
+			gs_app_list_length (apps),
+			gs_app_list_length (update_online),
+			gs_app_list_length (update_offline),
+			should_download ? "" : " not");
+
+		if (should_download && gs_app_list_length (update_online) > 0) {
+			g_autoptr(GsPluginJob) plugin_job = NULL;
+
+			plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_DOWNLOAD,
+							 "list", update_online,
+							 "propagate-error", TRUE,
+							 NULL);
+			g_debug ("Getting %u online updates", gs_app_list_length (update_online));
+			gs_plugin_loader_job_process_async (monitor->plugin_loader,
+							    plugin_job,
+							    monitor->cancellable,
+							    download_finished_cb,
+							    monitor);
+		}
+
+		if (should_download)
+			notify_list = update_offline;
+		else
+			notify_list = apps;
+
+		notify_about_pending_updates (monitor, notify_list);
 		reset_update_notification_timestamp (monitor);
 	}
 }
